@@ -10,7 +10,6 @@ import json
 import lxml.etree
 import os
 import pycountry
-import six
 import sys
 
 # If this script is renamed to 'xml2rfc.py' on a Windows system, the import
@@ -68,10 +67,7 @@ def print_country_help(options, parser):
     ids = list(country_ids.values())
     ids.sort()
     print('Known country codes and country names for use with <country>:\n')
-    if six.PY3:
-        print(('\n'.join([ '  '+'  -  '.join(v) for v in ids])))
-    else:
-        print(('\n'.join([ '  '+'  -  '.join(v) for v in ids])).encode('utf-8'))
+    print(('\n'.join([ '  '+'  -  '.join(v) for v in ids])))
     sys.exit()
 
 
@@ -89,25 +85,18 @@ def get_pdf_help(missing_libs=""):
 
         pip install 'weasyprint>=53.0,!=57.0,!=60.0'
 
+    3. Finally, install the required fonts:
+       * Download latest fonts from xml2rfc-fonts.
+         https://github.com/ietf-tools/xml2rfc-fonts/releases/latest
 
-    3. Finally, install the full Noto Font and Roboto Mono packages:
+       * In the "Assets" section, download either the tar.gz or
+         the zip archive.
 
-       * Download the full font file from:
-         https://noto-website-2.storage.googleapis.com/pkgs/Noto-unhinted.zip
-         or follow the 'DOWNLOAD ALL FONTS' link on this page:
-         https://www.google.com/get/noto/
+       * Extract the contents of the downloaded xml2rfc-fonts archive.
 
-       * Follow the installation instructions at
-         https://www.google.com/get/noto/help/install/
+       * Install the fonts found in the noto and roboto_mono directories
+         to your operating system.
 
-       * Go to https://fonts.google.com/specimen/Roboto+Mono, and download the
-         font. Follow the installation instructions above, as applied to this
-         download.
-
-       * Go to https://fonts.google.com/noto/specimen/Noto+Sans+Math, and
-         download the font. Follow the installation instructions above, as
-         applied to this download.
-    
     With these libraries, modules, and fonts installed and available to
     xml2rfc, the --pdf switch will be enabled.
     """
@@ -774,12 +763,8 @@ def main():
             xmlrfc.tree = prep.prep()
             if xmlrfc.tree:
                 info = extract_anchor_info(xmlrfc.tree)
-                if six.PY2:
-                    with open(filename, 'w') as fp:
-                        json.dump(info, fp, indent=2, ensure_ascii=False, encoding='utf-8')
-                else:
-                    with io.open(filename, 'w', encoding='utf-8') as fp:
-                        json.dump(info, fp, indent=2, ensure_ascii=False)
+                with io.open(filename, 'w', encoding='utf-8') as fp:
+                    json.dump(info, fp, indent=2, ensure_ascii=False)
                 if not options.quiet:
                     xml2rfc.log.write('Created file', filename)
 
